;Filename: TCap.s
;Part: ADuC703x.
;Created: 12/04/2006
;Author: Eckart Hartmann of Analog Devices
;This file is in beta sampling.

;This software is supplied subject our standard software license agreement.
;A non-binding summary is as follows:
;"You may use the software in your own code at your own risk.
;" ADI inc disclaims any warranty or liability of its use".
;The full standard software license agreement is available on request and
; remains the binding agreement.

#include        "..\Fla\ADuC703xi.equ"
Z_TnLD      DEFINE  0x300
Z_TnVAL     DEFINE  0x304
Z_TnCON     DEFINE  0x308
Z_TnCLRI    DEFINE  0x30c
Z_TnCAP     DEFINE  0x310

; TCap==========Reads timer capture register and sets the Capture register.
; C Function prototype: int TCap(int iT, int iCapCh);
;iT:{T_T1,T_T4}
;iCapCh:{I0FF,IT0,IT1,IT2,IT3,IFLA,IADC,IPLLL,II2C0S,II2C0M,II2C1M,ISPIS,ISPIM,IUART,IEX0,ICMP,IPSM,IEX1,IPLA0,IPLA1,IEX2,IEX3,IPWMT,IPWMS}
; Description of Function: Reads T1 or T4 capture register TCAP.
; User interface:
;   Set iT to desired Timer, 1 or 4.
;   Set iCapCh to the desired capture trigger source.
;     -1 = Only read capture register.
;      0 = IOFF -> capture off.    14 = IUART => UART
;      2 = IT0 => T0               15 = IEX0 => External interupt 0
;      3 = IT1 => T1               16 = ICMP => Comparator
;      4 = IT2 => T2               17 = IPSM => PSM
;      5 = IT3 => T3               18 = IEX1 => External interupt 1
;      6 = IFLA => Flash           19 = IPLA0 => PLA0
;      7 = IADC => ADC ready       20 = IPLA1 => PLA1
;      8 = IPLLL => PLL lock       21 = IEX2 => External interupt 2
;      9 = II2C0S => I2C0 slave    22 = IEX3 => External interupt 3
;      10 = II2C0M => I2C0 master  23 = IPWMT => PWM trip
;      11 = II2C1M => I2C1 master  24 = IPWMS => PWM sync
;      12 = ISPIS => SPI slave
;      13 = ISPIM => SPI master
;   Note: This table mirrors the IRQ/FIQ MMR bit definitions except for
;           bit 0 and 1. The values are 2 more than bits 12 to 16 of TnCON.
;   Call TCap(iT, iCapCh).
;   Returns TnCAP in r0.
; Robustness:
;  Interupt functionality may be added separately.
;  Will have no effect if iT is not 1 or 4.
; Side effects: Corrupts r0 and r3.

                RSEG CODE
                MODULE TCap
                PUBLIC TCap
                CODE32

TCap:   cmp     r0,#4
        cmpne   r0,#1
        cmpne   r0,#0
        bne     TCapR
        mov     r3,#0xff0000            ;r3 = Z_BASE
        orr     r3,r3,#0xff000000
        orr     r3,r3,r0,lsl#5          ;Z_BASE |= r0<<5;
        cmp     r1,#-0x01               ;if(r1 != -1)

        ldrne   r2,[r3,#Z_TnCON]        ; { r2 = TnCON;
        bicne   r2,r2,#0x3f000          ; Clear bits to replace.
        and     r1,r1,#0x1f
        orrne   r2,r2,r1,lsl#0x0c       ; r2 |= iCapCh<<12;
        orrne   r2,r2,#0x20000          ; set event select bit
        strne   r2,[r3,#Z_TnCON]        ; TnCON = r2; }

        ldr     r0,[r3,#Z_TnCAP]        ;r0 = TnCAP.
TCapR:  bx      lr

                 ENDMOD  TCap
                 END

